<!--
SPDX-FileCopyrightText: 2022 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# extras

Extras directory that contains functions that need additional dependencies to work.

| File      | Description |
| :-------: | :---------: |
| d3.py     | D3 dispersion correction |
| fods.py   | FOD generation |
| gui.py    | Notebook display functions |
| hdf5.py   | HDF5 file handling |
| libxc.py  | Use Libxc functionals |
